<?php

namespace Bixo\Social\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Social\Actions\CampaignAction;
use Bixo\Social\Http\Requests\CampaignActionRequest;
use Bixo\Social\Http\Resources\CampaignResource;
use Bixo\Social\Models\Campaign;

/**
 * Admin web controller class.
 */
class CampaignActionController extends BaseController
{

    /**
     * Action controller function for campaign.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CampaignActionRequest $request, Campaign $campaign, $action)
    {
        try {
            $request = $request->all();
            $campaign = CampaignAction::run($action, $campaign, $request);

            $data = new CampaignResource($campaign);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('social::campaign.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('social/campaign/' . $campaign->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('social/campaign/' . $campaign->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
