<?php

namespace Bixo\Social\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Social\Events\CampaignAction as CampaignActionEvent;
use Bixo\Social\Notifications\CampaignAction as CampaignActionNotification;
use Litepie\Actions\Concerns\AsAction;

class CampaignAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the CampaignActionEvent.
     *
     * @param   CampaignActionEvent  $event
     * @return mixed
     */
    public function handle(CampaignActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $campaign.
     *
     * @param   CampaignActionEvent  $event
     * @return void
     */
    public function create(CampaignActionEvent $event)
    {
        $client = $event->campaign->client;
        Notification::send($client, new CampaignActionNotification($event));
    }

    /**
     * Handle the CampaignActionEvent as a listener.
     *
     * @param   CampaignActionEvent  $event
     * @return mixed
     */
    public function asListener(CampaignActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   CampaignActionEvent  $event
     * @return bool
     */
    private function isAllowed(CampaignActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
