<?php
namespace Bixo\Social\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Social\Events\CampaignAction as CampaignActionEvent;
use Bixo\Social\Models\Campaign;

class CampaignAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $campaign;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param CampaignActionEvent $campaign
     */
    public function __construct(CampaignActionEvent $campaign)
    {
        $this->action = $event->action;
        $this->campaign = $campaign;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Campaign Approved - ' . config('app.name'))
            ->view('social::campaign.email.action', ['data' => $this->campaign]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
