<?php

namespace Bixo\Social\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Social\Models\Campaign;

class CampaignPolicy
{

    use CampaignAction;
    use CampaignReport;
    use CampaignWorkflow;

    /**
     * Determine if the given user can view the campaign.
     *
     * @param Authenticatable $user
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function view(Authenticatable $user, Campaign $campaign)
    {
        if ($authUser->canDo('social.campaign.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $campaign->is_owner;
    }

    /**
     * Determine if the given user can create a campaign.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('social.campaign.create');
    }

    /**
     * Determine if the given user can update the given campaign.
     *
     * @param Authenticatable $user
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function update(Authenticatable $user, Campaign $campaign)
    {
        if ($user->canDo('social.campaign.edit') && $user->isAdmin()) {
            return true;
        }

        return $campaign->is_owner;
    }

    /**
     * Determine if the given user can delete the given campaign.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Campaign $campaign)
    {
        return $campaign->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
