<?php

namespace Bixo\Social\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Social\Models\User;

class UserPolicy
{

    use UserAction;
    use UserReport;
    use UserWorkflow;

    /**
     * Determine if the given user can view the user.
     *
     * @param Authenticatable $user
     * @param User $user
     *
     * @return bool
     */
    public function view(Authenticatable $user, User $user)
    {
        if ($authUser->canDo('social.user.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $user->is_owner;
    }

    /**
     * Determine if the given user can create a user.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('social.user.create');
    }

    /**
     * Determine if the given user can update the given user.
     *
     * @param Authenticatable $user
     * @param User $user
     *
     * @return bool
     */
    public function update(Authenticatable $user, User $user)
    {
        if ($user->canDo('social.user.edit') && $user->isAdmin()) {
            return true;
        }

        return $user->is_owner;
    }

    /**
     * Determine if the given user can delete the given user.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, User $user)
    {
        return $user->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
